;---------------------Event Construction Blocks v1.1--------------------------------
;-------------------------------OmegaDragnet9---------------------------------------

;Based very heavily off of documentation by Kejardon.
;The principle of the PLM works very similarly to an example PLM
;in the PLM Details.txt file.

;https://patrickjohnston.org/ASM/ROM%20data/Super%20Metroid/Kejardon's%20docs/PLM_Details.txt

;Places air blocks that turn solid, displaying a graphic
;from the room's tile table.

;The GFX is masked by #$0FFF
;The Block type is masked by #$F000
;Does NOT set an event, but it checks for an event matching the Room Index number.
;Only after that is satisfied will you see the change in the room. 

;Known Bug:
;Must be placed 4 tiles horizontally far from a door tile.
;Must be placed 3 tiles vertically beyond a vertical door tile. 
;If you don't abide by this, the old GFX will load until you walk off-screen. 

lorom

;------------------------PLM Header-----------------------------------------------

!84Freespace = $84FDD0
 	
org !84Freespace

DW Setup
DW InstList 

;---------------------------Pre-Instruction---------------------------------------

Setup:  
LDA $079D				;Loads Room Index Number
JSL $808233				;Check against Event A
BCC +

;If Event is satisfied, this pre-instruction runs.
;This determines the GFX to display. 

;Adding $0400 in the editor will flip the tiles HORIZONTALLY
;Adding $0800 in the editor will flip the tiles VERTICALLY

LDX $1C87,y 			;PLM's location in the room (nth block * 2)  
PHY
LDY $1C27				;PLM index
LDA $1DC7,y				;PLM variable (GFX to load)
AND #$0FFF
PLY
STA $7F0002,x			;Creates airblock with that tile

;Checks High Nybble for Block Type:
PHX 
LDX $1C27
LDA $1DC7,x
AND #$F000
PLX

;This PLM utilizes a variation off a Vanilla Routine.
;By default if you simply masked the High Byte and JSR to $82B4, you would get whatever
;default BTS behavior with block "$00" would give you.
;This gives you a more practical selection of BTS blocks.
;This section can be expanded, but it's your responsibility to update that in the XML file. 

CMP #$0000 : BEQ .Solid 
CMP #$1000 : BEQ .Shot
CMP #$2000 : BEQ .Bomb 
CMP #$3000 : BEQ .Crumble
CMP #$4000 : BEQ .Speedboost
CMP #$5000 : BEQ .Enemyblock
CMP #$6000 : BEQ .Airbomb
CMP #$7000 : BEQ .Airshot
CMP #$8000 : BEQ .Air

.Solid
LDA #$800F : JSR $82B4 : RTS	;Creates BTS Behavior in this spot. 

.Shot
LDA #$C004 : JSR $82B4 : RTS	;Creates BTS Behavior in this spot. 

.Bomb
LDA #$F004 : JSR $82B4 : RTS	;Creates BTS Behavior in this spot. 

.Crumble
LDA #$B004 : JSR $82B4 : RTS	;Creates BTS Behavior in this spot. 

.Speedboost
LDA #$B01F : JSR $82B4 : RTS 	;Creates BTS Behavior in this spot. 

.Enemyblock
LDA #$A00F : JSR $82B4 : RTS	;Creates BTS Behavior in this spot. 

.Airbomb
LDA #$7004 : JSR $82B4 : RTS	;Creates BTS Behavior in this spot. 

.Airshot
LDA #$4004 : JSR $82B4 : RTS	;Creates BTS Behavior in this spot. 

.Air
RTS

;Make PLM block air, normal behavior.
;This is the Pre-instruction that runs if the Event is NOT set. 

+
LDX $1C87,y
LDA #$00FF				;Loads Tile in Tilemap,  
STA $7F0002,x
RTS

;--------------------Instruction List----------------------------------------

InstList:
DW $86B4				; Sleep














